@@ -1330,9 +1330,12 @@ class VariableOsLocationFormat(LocationHelper, Variable):
         if self.Get('os_root_type_ext') in RootType.HDD:
             root_format = self.select(
                 'os_disk_format', os_disk_mount="/", limit=1)
-            if root_format and self.select(
-                'os_format_use', os_format_type=root_format, limit=1) == "yes":
-                default_format = root_format
+            autoformat = self.Get('cl_autopartition_default_format')
+            for _format in (root_format, autoformat):
+                if _format and self.select(
+                    'os_format_use', os_format_type=_format, limit=1) == "yes":
+                    default_format = _format
+                    break
 
         def wrap(info):
             dev, mount, fs = info
